from typing import Dict

from langchain_core.utils import get_from_dict_or_env
from pydantic.v1 import root_validator, BaseModel
from tmdbv3api import TMDb, Movie


class TMDBWrapper(BaseModel):
    openai_api_key: str
    tmdb_api_key: str

    class Config:
        extra = "forbid"

    # noinspection PyMethodParameters
    @root_validator(pre=True)
    def validate_environment(cls, values: Dict) -> Dict:
        """Validate that api key and endpoint exists in environment."""
        tmdb_api_key = get_from_dict_or_env(
            values, "tmdb_api_key", "TMDB_API_KEY"
        )
        values["tmdb_api_key"] = tmdb_api_key

        openai_api_key = get_from_dict_or_env(
            values, "openai_api_key", "OPENAI_API_KEY"
        )
        values["openai_api_key"] = openai_api_key

        return values

    # region(ISO 3166-1)
    def get_movie_now_playing(self, region=None):
        tmdb = TMDb()
        tmdb.api_key = self.tmdb_api_key
        tmdb.language = 'en'

        movie = Movie()
        new_movies = movie.now_playing(region)
        # for m in new_movies:
        #     print(f"Title: {m.title}")
        #     print(f"Release Date: {m.release_date}")
        #     print(f"Overview: {m.overview}")
        #     print("-" * 50)
        return new_movies

    # region(ISO 3166-1)
    def get_movie_popular(self, region=None):
        tmdb = TMDb()
        tmdb.api_key = self.tmdb_api_key
        tmdb.language = 'en'

        movie = Movie()
        new_movies = movie.popular(region)
        return new_movies
